==> angular-pouchdb-logger-0.7.0.tgz: package/CHANGELOG.md <==
<a name="0.7.0"></a>
# [0.7.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.6.0...v0.7.0) (2017-07-17)


### Features

* **info-logging:** Allow disabling of info logging ([ff11686](https://github.com/hypery2k/angular-pouchdb-logger/commit/ff11686))
* **WKWebView:** Adding support for WKWebView and idb ([23f0b7f](https://github.com/hypery2k/angular-pouchdb-logger/commit/23f0b7f))



<a name="0.6.0"></a>
# [0.6.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.5.0...v0.6.0) (2017-03-18)


### Features

* **info-logging:** Allow disabling of info logging ([d4627de](https://github.com/hypery2k/angular-pouchdb-logger/commit/d4627de))



<a name="0.5.0"></a>
# [0.5.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/0.3.5...v0.5.0) (2017-01-08)


### Features

* **logging:** Support all arg logging ([53dabf2](https://github.com/hypery2k/angular-pouchdb-logger/commit/53dabf2))



<a name="0.3.5"></a>
## [0.3.5](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.4...0.3.5) (2016-08-14)



<a name="0.3.4"></a>
## [0.3.4](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.3...v0.3.4) (2016-07-17)



<a name="0.3.3"></a>
## [0.3.3](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.2...v0.3.3) (2016-07-17)



<a name="0.3.2"></a>
## [0.3.2](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.1...v0.3.2) (2016-06-27)



<a name="0.3.1"></a>
## [0.3.1](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.0...v0.3.1) (2016-06-26)



<a name="0.3.0"></a>
# [0.3.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.3...v0.3.0) (2016-06-26)



<a name="0.2.3"></a>
## [0.2.3](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.2...v0.2.3) (2016-06-26)



<a name="0.2.2"></a>
## [0.2.2](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.1...v0.2.2) (2015-10-23)



<a name="0.2.1"></a>
## [0.2.1](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.0...v0.2.1) (2015-10-20)



<a name="0.2.0"></a>
# [0.2.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.1.0...v0.2.0) (2015-10-20)



<a name="0.1.0"></a>
# 0.1.0 (2015-10-20)

==> angular-pouchdb-logger-0.8.0.tgz: package/CHANGELOG.md <==
<a name="0.8.0"></a>
# [0.8.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.7.0...v0.8.0) (2017-07-18)


### Features

* **cordova:** Support for cordova-sqlite ([f2cb15c](https://github.com/hypery2k/angular-pouchdb-logger/commit/f2cb15c))



<a name="0.7.0"></a>
# [0.7.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.6.0...v0.7.0) (2017-07-17)


### Features

* **info-logging:** Allow disabling of info logging ([ff11686](https://github.com/hypery2k/angular-pouchdb-logger/commit/ff11686))
* **WKWebView:** Adding support for WKWebView and idb ([23f0b7f](https://github.com/hypery2k/angular-pouchdb-logger/commit/23f0b7f))



<a name="0.6.0"></a>
# [0.6.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.5.0...v0.6.0) (2017-03-18)


### Features

* **info-logging:** Allow disabling of info logging ([d4627de](https://github.com/hypery2k/angular-pouchdb-logger/commit/d4627de))



<a name="0.5.0"></a>
# [0.5.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.4.0...v0.5.0) (2017-01-08)



<a name="0.4.0"></a>
# [0.4.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/0.3.5...v0.4.0) (2016-12-12)


### Features

* **logging:** Support all arg logging ([53dabf2](https://github.com/hypery2k/angular-pouchdb-logger/commit/53dabf2))



<a name="0.3.5"></a>
## [0.3.5](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.4...0.3.5) (2016-08-14)



<a name="0.3.4"></a>
## [0.3.4](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.3...v0.3.4) (2016-07-17)



<a name="0.3.3"></a>
## [0.3.3](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.2...v0.3.3) (2016-07-17)



<a name="0.3.2"></a>
## [0.3.2](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.1...v0.3.2) (2016-06-27)



<a name="0.3.1"></a>
## [0.3.1](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.3.0...v0.3.1) (2016-06-26)



<a name="0.3.0"></a>
# [0.3.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.3...v0.3.0) (2016-06-26)



<a name="0.2.3"></a>
## [0.2.3](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.2...v0.2.3) (2016-06-26)



<a name="0.2.2"></a>
## [0.2.2](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.1...v0.2.2) (2015-10-23)



<a name="0.2.1"></a>
## [0.2.1](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.2.0...v0.2.1) (2015-10-20)



<a name="0.2.0"></a>
# [0.2.0](https://github.com/hypery2k/angular-pouchdb-logger/compare/v0.1.0...v0.2.0) (2015-10-20)



<a name="0.1.0"></a>
# 0.1.0 (2015-10-20)
